Attribute VB_Name = "InBrowser"

'=================================================================
'Description: Outlook macro which allows you to open the selected
'             message in a browser of your choice instead of the
'             ancient Internet Explorer.
'
'author : Robert Sparnaaij
'version: 1.0
'website: https://www.howto-outlook.com/howto/openinbrowser.htm
'=================================================================

Sub OpenInBrowser()

    Dim BrowserLocation As String
    Dim AlwaysConvert As Boolean
    Dim EvaluateHTML As Boolean
    
    '=============Set your variables in the section below==========================
    'The default settings are optimized for viewing newsletters and receiving
    'messages with HTML forms or animated gif-files embedded in the message.
    
    'Set the location of the executable of the browser you want to use.
    'Standard value: "C:\Program Files\Internet Explorer\iexplore.exe"
    BrowserLocation = "C:\Program Files\Internet Explorer\iexplore.exe"
    
    'When set to True, we will let Outlook convert the message to HTML.
    'The message will be opened in the configured browser just as it
    'appears in Outlook.
    'Standard value: False
    AlwaysConvert = False
    
    'When set to True, we will look for embedded resources in the HTML message and
    'determine whether Outlook should convert the message or whether we can strip
    'the HTML directly. When set to False, we will always strip the HTML and ignore
    'embedded resources.
    'For this setting to take effect, AlwaysConvert must be set to False.
    'Standard value: True
    EvaluateHTML = True
    
    '=======Don't modify the code below unless you know what you are doing=========
    
    'Get the user's TempFolder to store the item in
    Dim FSO As Object, TmpFolder As Object
    Set FSO = CreateObject("scripting.filesystemobject")
    Set TempFolder = FSO.GetSpecialFolder(2)

    'Get all selected items
    Dim objOL As Outlook.Application
    Dim objSelection As Outlook.Selection
    Dim MySelectedItem As Object
    Set objOL = Outlook.Application
    Set objSelection = objOL.ActiveExplorer.Selection

    'Make sure at least one item is selected
    If objSelection.Count <> 1 Then
       Response = MsgBox("Please select a single item", vbExclamation, "Open in Browser")
       Exit Sub
    End If

    'Retrieve the selected item
    Set MySelectedItem = objSelection.Item(1)
    
    'construct the filename
    Dim FileName As String
    strname = "www_howto-outlook_com"
    FileName = TempFolder & "\" & strname & ".htm"
    
    'If the message is in HTML format we directly capture the HTML from the message
    'to construct our htm-file. This will allow us to capture as many HTML elements
    'as possible. If it is a different format, or if the HTML mail includes embedded
    'resources we let Outlook convert it to HTML.
    Dim OutlookConvert As Boolean
    OutlookConvert = True
    
    If MySelectedItem.BodyFormat = olFormatHTML And AlwaysConvert = False Then
        Dim rawHTML As String
        rawHTML = MySelectedItem.HTMLBody
        
        If EvaluateHTML = False Then
            OutlookConvert = False
        Else
            'Check if there are embedded resources in the message.
            'If it does, we let Outlook convert the message.
            If InStr(UCase(rawHTML), UCase("src=""cid:")) = 0 Then
                OutlookConvert = False
            End If
        End If
    End If
    
    'Write the temp-file
    If OutlookConvert = False Then
            'create the htm-file in the temp folder and write the HTML code to it
            Set objFile = FSO.CreateTextFile(FileName, True)
            objFile.Write "" & rawHTML
            objFile.Close
            Set objFile = Nothing
    Else
            'let Outlook convert the message and save the selected item
            'as htm to the temp folder
            MySelectedItem.SaveAs FileName, olHTML
    End If
    
    'open the saved item in the browser
    Shell BrowserLocation & " " & FileName, vbNormalFocus
    
    'Cleanup
    Set FSO = Nothing
    Set TempFolder = Nothing
    Set objOL = Nothing
    Set objSelection = Nothing
    Set MySelectedItem = Nothing

End Sub